@@ -59,7 +59,7 @@ class TestEso:
         with pytest.raises(LoginError) as exc:
             eso.retrieve_data('AMBER.2006-03-14T07:40:19.830')
 
-        assert exc.value.args[0] == "Not logged in.  You must be logged in to download data."
+        assert exc.value.args[0] == "If you do not pass a username to login(), you should configure a default one!"
 
     def test_empty_return(self):
         # test for empty return with an object from the North
@@ -91,10 +91,10 @@ class TestEso:
 
         inst = Eso.list_instruments()
 
-        assert inst == ['fors1', 'fors2', 'vimos', 'omegacam', 'hawki', 'isaac',
-                        'naco', 'visir', 'vircam', 'apex', 'uves', 'giraffe',
-                        'xshooter', 'crires', 'kmos', 'sinfoni', 'amber',
-                        'midi', 'harps']
+        assert inst == [u'fors1', u'fors2', u'vimos', u'omegacam', u'hawki', u'isaac',
+                        u'naco', u'visir', u'vircam', u'apex', u'uves', u'giraffe',
+                        u'xshooter', u'muse', u'crires', u'kmos', u'sinfoni', u'amber',
+                        u'midi', u'harps']
 
     # REQUIRES LOGIN!
     # Can we get a special login specifically for astroquery testing?
@@ -104,3 +104,18 @@ class TestEso:
     #    data_files = eso.retrieve_data([data_product_id])
     #    # How do we know if we're going to get .fits or .fits.Z?
     #    assert 'AMBER.2006-03-14T07:40:03.741.fits' in data_files[0]
+    
+    @pytest.mark.skipif('not Eso.USERNAME')
+    def test_retrieve_data(self):
+        eso = Eso()
+        eso.login()
+        result = eso.retrieve_data("MIDI.2014-07-25T02:03:11.561")
+        assert len(result)>0
+        assert "MIDI.2014-07-25T02:03:11.561" in result[0]
+
+    @pytest.mark.skipif('not Eso.USERNAME')
+    def test_retrieve_data_twice(self):
+        eso = Eso()
+        eso.login()
+        result1 = eso.retrieve_data("MIDI.2014-07-25T02:03:11.561")
+        result2 = eso.retrieve_data("AMBER.2006-03-14T07:40:19.830")
