@@ -17,39 +17,10 @@ import astropy.utils.data
 __all__ = ['BaseQuery', 'QueryWithLogin']
 
 
-class AstroResponse(object):
-
-    def __init__(self, response=None, url=None, encoding=None, content=None,
-                 stream=False):
-        if response is None:
-            self.url = url
-            self.encoding = encoding
-            self.content = content
-            self.text = content.text
-        elif isinstance(response, requests.Response):
-            self.url = response.url
-            self.encoding = response.encoding
-            self.text = response.text
-            if stream:
-                self.iter_content = response.iter_content
-            self.content = response.content
-            # Needed for assessing file size:
-            self.headers = response.headers
-        elif not hasattr(response, 'content'):
-            raise TypeError("{0} is not a requests.Response".format(response))
-        elif not isinstance(response, requests.Response):
-            self.url = response.url
-            self.content = response.content
-            self.text = response.text
-            warnings.warn("Response has 'content' attribute but is not a "
-                          "requests.Response object.  This is expected when "
-                          "running local tests but not otherwise.")
-        else:
-            raise ValueError("Empty AstroResponse created.")
-
-    def to_cache(self, cache_file):
-        with open(cache_file, "wb") as f:
-            pickle.dump(self, f)
+def to_cache(response, cache_file):
+    log.debug("Caching data to {0}".format(cache_file))
+    with open(cache_file, "wb") as f:
+        pickle.dump(response, f)
 
 
 class AstroQuery(object):
@@ -76,14 +47,11 @@ class AstroQuery(object):
         else:
             self._timeout = value
 
-    def request(self, session, cache_location=None, stream=False):
-        return AstroResponse(session.request(self.method, self.url,
-                                             params=self.params,
-                                             data=self.data,
-                                             headers=self.headers,
-                                             files=self.files,
-                                             timeout=self.timeout,
-                                             stream=stream))
+    def request(self, session, cache_location=None, stream=False, auth=None):
+        return session.request(self.method, self.url, params=self.params,
+                               data=self.data, headers=self.headers,
+                               files=self.files, timeout=self.timeout,
+                               stream=stream, auth=auth)
 
     def hash(self):
         if self._hash is None:
@@ -103,17 +71,20 @@ class AstroQuery(object):
         return self._hash
 
     def request_file(self, cache_location):
-        return os.path.join(cache_location, self.hash() + ".pickle")
+        fn = os.path.join(cache_location, self.hash() + ".pickle")
+        return fn
 
     def from_cache(self, cache_location):
         request_file = self.request_file(cache_location)
         try:
             with open(request_file, "rb") as f:
                 response = pickle.load(f)
-            if not isinstance(response, AstroResponse):
+            if not isinstance(response, requests.Response):
                 response = None
         except:
             response = None
+        if response:
+            log.debug("Retrieving data from {0}".format(request_file))
         return response
 
 
@@ -125,7 +96,7 @@ class BaseQuery(object):
     """
 
     def __init__(self):
-        self.__session = requests.session()
+        self._session = requests.session()
         self.cache_location = os.path.join(paths.get_cache_dir(), 'astroquery',
                                            self.__class__.__name__.split("Class")[0])
         if not os.path.exists(self.cache_location):
@@ -138,7 +109,7 @@ class BaseQuery(object):
 
     def _request(self, method, url, params=None, data=None, headers=None,
                  files=None, save=False, savedir='', timeout=None, cache=True,
-                 stream=False):
+                 stream=False, auth=None):
         """
         A generic HTTP request method, similar to `requests.Session.request` but
         with added caching-related tools
@@ -154,21 +125,32 @@ class BaseQuery(object):
         params : None or dict
         data : None or dict
         headers : None or dict
+        auth : None or dict
         files : None or dict
             See `requests.request`
         save : bool
-            Whether to save the file to a local directory.  Caching will happen independent of
-            this parameter if `BaseQuery.cache_location` is set, but the save location can be
-            overridden if ``save==True``
+            Whether to save the file to a local directory.  Caching will happen
+            independent of this parameter if `BaseQuery.cache_location` is set,
+            but the save location can be overridden if ``save==True``
         savedir : str
             The location to save the local file if you want to save it
             somewhere other than `BaseQuery.cache_location`
+
+        Returns
+        -------
+        response : `requests.Response`
+            The response from the server if ``save`` is False
+        local_filepath : list
+            a list of strings containing the downloaded local paths if ``save``
+            is True
         """
         if save:
             local_filename = url.split('/')[-1]
-            local_filepath = os.path.join(self.cache_location or savedir or '.', local_filename)
+            local_filepath = os.path.join(self.cache_location or savedir or
+                                          '.', local_filename)
             log.info("Downloading {0}...".format(local_filename))
-            self._download_file(url, local_filepath, timeout=timeout)
+            self._download_file(url, local_filepath, timeout=timeout,
+                                auth=auth)
             return local_filepath
         else:
             query = AstroQuery(method, url, params=params, data=data,
@@ -176,22 +158,25 @@ class BaseQuery(object):
             if ((self.cache_location is None) or (not self._cache_active) or
                 (not cache)):
                 with suspend_cache(self):
-                    response = query.request(self.__session, stream=stream)
+                    response = query.request(self._session, stream=stream,
+                                             auth=auth)
             else:
                 response = query.from_cache(self.cache_location)
                 if not response:
-                    response = query.request(self.__session,
+                    response = query.request(self._session,
                                              self.cache_location,
-                                             stream=stream)
-                    response.to_cache(query.request_file(self.cache_location))
+                                             stream=stream,
+                                             auth=auth)
+                    to_cache(response, query.request_file(self.cache_location))
             return response
 
-    def _download_file(self, url, local_filepath, timeout=None):
+    def _download_file(self, url, local_filepath, timeout=None, auth=None):
         """
         Download a file.  Resembles `astropy.utils.data.download_file` but uses
-        the local ``__session``
+        the local ``_session``
         """
-        response = self.__session.get(url, timeout=timeout, stream=True)
+        response = self._session.get(url, timeout=timeout, stream=True,
+                                      auth=auth)
         if 'content-length' in response.headers:
             length = int(response.headers['content-length'])
         else:
@@ -237,6 +222,10 @@ class QueryWithLogin(BaseQuery):
     are not stored in the cache.
     """
 
+    def __init__(self):
+        super(QueryWithLogin, self).__init__()
+        self._authenticated = False
+
     @abc.abstractmethod
     def _login(self, *args, **kwargs):
         """
@@ -251,5 +240,8 @@ class QueryWithLogin(BaseQuery):
 
     def login(self, *args, **kwargs):
         with suspend_cache(self):
-            result = self._login(*args, **kwargs)
-        return result
+            self._authenticated = self._login(*args, **kwargs)
+        return self._authenticated
+
+    def authenticated(self):
+        return self._authenticated
